==> kubernetes-model-1.0.47-sources.jar: annotations/io/fabric8/openshift/api/model/NamedClusterRoleBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import io.fabric8.kubernetes.api.model.HasMetadata;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class NamedClusterRoleBuilder extends NamedClusterRoleFluentImpl<NamedClusterRoleBuilder> implements VisitableBuilder<NamedClusterRole,NamedClusterRoleBuilder>{

     NamedClusterRoleFluent<?> fluent;
public NamedClusterRoleBuilder(){
    this(new NamedClusterRole());
}
public NamedClusterRoleBuilder( NamedClusterRoleFluent<?> fluent ){
    this(fluent, new NamedClusterRole());
}
public NamedClusterRoleBuilder( NamedClusterRoleFluent<?> fluent , NamedClusterRole instance ){
    this.fluent = fluent; fluent.withName(instance.getName()); fluent.withRole(instance.getRole()); 
}
public NamedClusterRoleBuilder( NamedClusterRole instance ){
    this.fluent = this; this.withName(instance.getName()); this.withRole(instance.getRole()); 
}

public EditableNamedClusterRole build(){
    EditableNamedClusterRole buildable = new EditableNamedClusterRole(fluent.getName(),fluent.getRole());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
NamedClusterRoleBuilder that = (NamedClusterRoleBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        Validator validator = factory.getValidator();
        
        Set<ConstraintViolation<T>> violations = validator.validate(item);
        if (!violations.isEmpty()) {
            StringBuilder sb = new StringBuilder();
            sb.append("Constraint Violations:\n");
            for (ConstraintViolation violation : violations) {
                sb.append("\t").append(violation.getRootBeanClass().getSimpleName()).append(" ").append(violation.getPropertyPath()).append(":").append(violation.getMessage()).append("\n");
            }
            throw new IllegalStateException(sb.toString());
        }
    } catch(ValidationException e) {
        //ignore
    }
}


}

==> kubernetes-model-1.0.50-sources.jar: annotations/io/fabric8/openshift/api/model/NamedClusterRoleBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import java.util.Set;
import io.fabric8.kubernetes.api.model.HasMetadata;
import java.util.HashMap;
import java.io.Serializable;
import java.util.Map;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import java.util.Map;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;

public class NamedClusterRoleBuilder extends NamedClusterRoleFluentImpl<NamedClusterRoleBuilder> implements VisitableBuilder<NamedClusterRole,NamedClusterRoleBuilder>{

     NamedClusterRoleFluent<?> fluent;
public NamedClusterRoleBuilder(){
    this(new NamedClusterRole());
}
public NamedClusterRoleBuilder( NamedClusterRoleFluent<?> fluent ){
    this(fluent, new NamedClusterRole());
}
public NamedClusterRoleBuilder( NamedClusterRoleFluent<?> fluent , NamedClusterRole instance ){
    this.fluent = fluent; fluent.withName(instance.getName()); fluent.withRole(instance.getRole()); 
}
public NamedClusterRoleBuilder( NamedClusterRole instance ){
    this.fluent = this; this.withName(instance.getName()); this.withRole(instance.getRole()); 
}

public NamedClusterRole build(){
    NamedClusterRole buildable = new NamedClusterRole(fluent.getName(),fluent.getRole());
validate(buildable);
return buildable;

}
public boolean equals( Object o ){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
if (!super.equals(o)) return false;
NamedClusterRoleBuilder that = (NamedClusterRoleBuilder) o;
if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
return true;

}

private <T> void validate(T item) {
    Validator validator = null;
    try {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        validator = factory.getValidator();
    } catch(ValidationException e) {
        //ignore
        return;
    }

    Set<ConstraintViolation<T>> violations = validator.validate(item);
    if (!violations.isEmpty()) {
        throw new ConstraintViolationException(violations);
    }
}

}
